@@ -1,16 +1,17 @@
 #!/bin/sh
 # SPDX-License-Identifier: BSD-2-Clause
 # SPDX-FileCopyrightText: © 2020 Antoine Le Gonidec <vv221@dotslashplay.it>
-# SPDX-FileCopyrightText: © 2021 Hoël Bézier
+# SPDX-FileCopyrightText: © 2021 Hoël Bézier <hoelbezier@riseup.net>
 set -o errexit
 
 ###
 # Age of Mythology
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241124.1
+script_version=20250605.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='age-of-mythology'
 GAME_NAME='Age of Mythology'
@@ -27,6 +28,7 @@ ARCHIVE_BASE_DEMO_0_URL='https://archive.org/details/AgeOfMythologyDemo'
 
 CONTENT_PATH_DEFAULT='aom'
 CONTENT_GAME_BIN_FILES='
+mp3dec.asi
 *.exe
 *.dll'
 CONTENT_GAME0_BIN_PATH='.'
@@ -42,9 +44,28 @@ georgiab.ttf
 georgiai.ttf
 georgia.ttf
 georgiaz.ttf'
-## TODO: An explicit list of files should be set
 CONTENT_GAME_DATA_FILES='
-*'
+ai
+anim
+avi
+data
+docs
+fonts
+gfxconfig
+god powers
+history
+models
+ppdata
+rm
+scenario
+sound
+startup
+textures
+trigger
+10??
+20??
+30??
+*.bmp'
 CONTENT_DOC_DATA_PATH='.'
 CONTENT_DOC_DATA_FILES='
 *.rtf'
@@ -63,6 +84,10 @@ savegame
 screenshots
 users'
 
+## Without a virtual desktop,
+## keyboard input is lost on loss of focus.
+WINE_VIRTUAL_DESKTOP='1600x1200'
+
 APP_MAIN_EXE='aom.exe'
 
 PACKAGES_LIST='
