@@ -5,9 +5,10 @@ set -o errexit
 
 ###
 # Grim Dawn
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250211.1
+script_version=20250603.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -147,10 +148,6 @@ texturecompiler.exe
 texviewer.exe
 viewer.exe
 *.dlo'
-## TODO: Check if the Galaxy library are required
-CONTENT_GAME0_BIN_FILES='
-galaxy.dll
-goggalaxyhooks.dll'
 CONTENT_GAME_DATA_FILES='
 database
 resources
