@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Little Inferno
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241227.1
+script_version=20250429.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='little-inferno'
 GAME_NAME='Little Inferno'
@@ -57,6 +58,10 @@ CONTENT_LIBS_BIN32_RELATIVE_PATH_32BIT='lib'
 CONTENT_LIBS_BIN32_FILES_32BIT='
 libvorbis.so.0'
 
+## When playing Little Inferno with Mesa, the game might be shown as a black screen or be full of black artifacts.
+## Switching out of fullscreen then back to it with the F key might help in mitigating the rendering issues.
+## A bug report has been sent to Mesa developers: https://gitlab.freedesktop.org/mesa/mesa/-/issues/7903
+## TODO: Support for the Windows build should be provided as an alternative.
 APP_MAIN_EXE_BIN64='LittleInferno.bin.x86_64'
 APP_MAIN_EXE_BIN32='LittleInferno.bin.x86'
 APP_MAIN_ICON='noarch/icon.png'
@@ -80,8 +85,6 @@ PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -90,8 +93,6 @@ libopenal.so.1
 libpthread.so.0
 libSDL2-2.0.so.0
 libstdc++.so.6'
-PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
-PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES_32BIT='
 libc.so.6
 libcurl.so.4
