@@ -11,9 +11,10 @@ set -o errexit
 # - The White March, Part 1
 # - The White March, Part 2
 # - Deadfire Pack
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241227.1
+script_version=20250403.2
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -42,6 +43,11 @@ EXPANSION_NAME_DEADFIRE='Deadfire Pack'
 
 ## Kickstarter item
 
+ARCHIVE_BASE_TIER1BACKER_1_NAME='pillars_of_eternity_kickstarter_item_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_TIER1BACKER_1_MD5='67b7ae65b7c1502e37110b7f4402a19f'
+ARCHIVE_BASE_TIER1BACKER_1_SIZE='971'
+ARCHIVE_BASE_TIER1BACKER_1_VERSION='3.8.0.87535-gog80946'
+
 ARCHIVE_BASE_TIER1BACKER_0_NAME='gog_pillars_of_eternity_kickstarter_item_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_TIER1BACKER_0_MD5='b4c29ae17c87956471f2d76d8931a4e5'
 ARCHIVE_BASE_TIER1BACKER_0_SIZE='924'
@@ -49,6 +55,11 @@ ARCHIVE_BASE_TIER1BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Kickstarter pet
 
+ARCHIVE_BASE_TIER2BACKER_1_NAME='pillars_of_eternity_kickstarter_pet_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_TIER2BACKER_1_MD5='f5ee7919aaf466d45c12689a4de327e9'
+ARCHIVE_BASE_TIER2BACKER_1_SIZE='978'
+ARCHIVE_BASE_TIER2BACKER_1_VERSION='3.8.0.87535-gog80946'
+
 ARCHIVE_BASE_TIER2BACKER_0_NAME='gog_pillars_of_eternity_kickstarter_pet_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_TIER2BACKER_0_MD5='3653fc2a98ef578335f89b607f0b7968'
 ARCHIVE_BASE_TIER2BACKER_0_SIZE='924'
@@ -56,6 +67,11 @@ ARCHIVE_BASE_TIER2BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Pre-order item and pet
 
+ARCHIVE_BASE_PREORDER_1_NAME='pillars_of_eternity_preorder_item_and_pet_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_PREORDER_1_MD5='ad7a6c20a937f76a356e1613495c43c0'
+ARCHIVE_BASE_PREORDER_1_SIZE='963'
+ARCHIVE_BASE_PREORDER_1_VERSION='3.8.0.87535-gog80946'
+
 ARCHIVE_BASE_PREORDER_0_NAME='gog_pillars_of_eternity_preorder_item_and_pet_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_PREORDER_0_MD5='b86ad866acb62937d2127407e4beab19'
 ARCHIVE_BASE_PREORDER_0_SIZE='924'
@@ -63,11 +79,16 @@ ARCHIVE_BASE_PREORDER_0_VERSION='1.0-gog2.0.0.2'
 
 ## The White March, Part 1
 
+ARCHIVE_BASE_TWM1_4_NAME='pillars_of_eternity_the_white_march_part_1_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_TWM1_4_MD5='ad2218672a0aba7ee0a30b73eefc81dd'
+ARCHIVE_BASE_TWM1_4_SIZE='7564726'
+ARCHIVE_BASE_TWM1_4_VERSION='3.8.0.87535-gog80946'
+ARCHIVE_BASE_TWM1_4_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_1'
+
 ARCHIVE_BASE_TWM1_3_NAME='pillars_of_eternity_white_march_part_1_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM1_3_MD5='cc72f59ee20238ff05c47646b4618f01'
 ARCHIVE_BASE_TWM1_3_SIZE='5507108'
 ARCHIVE_BASE_TWM1_3_VERSION='3.7.0.1318-gog17464'
-ARCHIVE_BASE_TWM1_3_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_1'
 
 ARCHIVE_BASE_TWM1_2_NAME='pillars_of_eternity_white_march_part_1_dlc_en_3_07_16598.sh'
 ARCHIVE_BASE_TWM1_2_MD5='054b6af430da1ed2635b9c6b4ed56866'
@@ -86,11 +107,16 @@ ARCHIVE_BASE_TWM1_0_VERSION='3.05.0.1186-gog2.9.0.11'
 
 ## The White March, Part 2
 
+ARCHIVE_BASE_TWM2_4_NAME='pillars_of_eternity_the_white_march_part_2_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_TWM2_4_MD5='b64f8528243197aaec1a6a99fb43e728'
+ARCHIVE_BASE_TWM2_4_SIZE='6845084'
+ARCHIVE_BASE_TWM2_4_VERSION='3.8.0.87535-gog80946'
+ARCHIVE_BASE_TWM2_4_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_2'
+
 ARCHIVE_BASE_TWM2_3_NAME='pillars_of_eternity_white_march_part_2_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM2_3_MD5='03067ebdd878cc16c283f63ddf015e90'
 ARCHIVE_BASE_TWM2_3_SIZE='4360158'
 ARCHIVE_BASE_TWM2_3_VERSION='3.7.0.1318-gog17464'
-ARCHIVE_BASE_TWM2_3_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_2'
 
 ARCHIVE_BASE_TWM2_2_NAME='pillars_of_eternity_white_march_part_2_dlc_en_3_07_16598.sh'
 ARCHIVE_BASE_TWM2_2_MD5='db3a345b2b2782e2ad075dd32567f303'
@@ -109,11 +135,16 @@ ARCHIVE_BASE_TWM2_0_VERSION='3.05.1186-gog2.5.0.6'
 
 ## Deadfire Pack
 
+ARCHIVE_BASE_DEADFIRE_3_NAME='pillars_of_eternity_deadfire_pack_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_DEADFIRE_3_MD5='ece6e59bc5bd1f59498140d3a4f1fb74'
+ARCHIVE_BASE_DEADFIRE_3_SIZE='73988'
+ARCHIVE_BASE_DEADFIRE_3_VERSION='3.8.0.87535-gog80946'
+ARCHIVE_BASE_DEADFIRE_3_URL='https://www.gog.com/game/pillars_of_eternity_deadfire_pack'
+
 ARCHIVE_BASE_DEADFIRE_2_NAME='pillars_of_eternity_deadfire_pack_dlc_en_3_07_0_1318_20099.sh'
 ARCHIVE_BASE_DEADFIRE_2_MD5='da315aba26784e55aa51139cebb7f9d2'
 ARCHIVE_BASE_DEADFIRE_2_SIZE='922'
 ARCHIVE_BASE_DEADFIRE_2_VERSION='3.07.0.1318-gog20099'
-ARCHIVE_BASE_DEADFIRE_2_URL='https://www.gog.com/game/pillars_of_eternity_deadfire_pack'
 
 ARCHIVE_BASE_DEADFIRE_1_NAME='pillars_of_eternity_deadfire_pack_dlc_en_3_07_0_1318_17462.sh'
 ARCHIVE_BASE_DEADFIRE_1_MD5='021362da5912dc8a3e47473e97726f7f'
@@ -129,6 +160,12 @@ ARCHIVE_BASE_DEADFIRE_0_VERSION='3.07-gog16380'
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 PillarsOfEternity_Data'
+CONTENT_GAME_MAIN_FILES_TIER1BACKER='
+PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/tier1backer*'
+CONTENT_GAME_MAIN_FILES_TIER2BACKER='
+PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/tier2backer*'
+CONTENT_GAME_MAIN_FILES_PREORDER='
+PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/tier1preorder*'
 
 PKG_PARENT_ID="$GAME_ID"
 PKG_TWM1_ID="${GAME_ID}-${EXPANSION_ID_TWM1}"
@@ -177,7 +214,9 @@ archive_extraction_default
 	# The White March, Part 2 - Remove a file already provided by a dependency
 	case "$(current_archive)" in
 		('ARCHIVE_BASE_TWM2_'*)
-			rm --force 'PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror.unity3d'
+			rm --force \
+				'PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror' \
+				'PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror.unity3d'
 		;;
 	esac
 
