@@ -6,20 +6,26 @@ set -o errexit
 
 ###
 # Pillars of Eternity
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241227.1
+script_version=20250403.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='pillars-of-eternity-1'
 GAME_NAME='Pillars of Eternity'
 
+ARCHIVE_BASE_4_NAME='pillars_of_eternity_3_8_0_87535_80946.sh'
+ARCHIVE_BASE_4_MD5='805f0a9f9d467937ae52cb33c5aa7515'
+ARCHIVE_BASE_4_SIZE='17022011'
+ARCHIVE_BASE_4_VERSION='3.8.0.87535-gog80946'
+ARCHIVE_BASE_4_URL='https://www.gog.com/game/pillars_of_eternity_hero_edition'
+
 ARCHIVE_BASE_3_NAME='pillars_of_eternity_en_3_07_0_1318_17461.sh'
 ARCHIVE_BASE_3_MD5='57164ad0cbc53d188dde0b38e7491916'
 ARCHIVE_BASE_3_SIZE='14801525'
 ARCHIVE_BASE_3_VERSION='3.7.0.1318-gog17461'
-ARCHIVE_BASE_3_URL='https://www.gog.com/game/pillars_of_eternity_hero_edition'
 
 ARCHIVE_BASE_2_NAME='pillars_of_eternity_en_3_07_16405.sh'
 ARCHIVE_BASE_2_MD5='e4271b5e72f1ecc9fbbc4d90937ede05'
