@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Pyre
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241027.1
+script_version=20250731.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='pyre'
 GAME_NAME='Pyre'
@@ -64,8 +65,17 @@ CONTENT_DOC_DATA_FILES='
 Linux.README
 ReadMe.txt'
 
-## The shipped binaries are used instead of system-provided Mono to avoid a crash on initial loading.
-## See notes/pyre for more details.
+## Using system-provided Mono 6.8.0.105, the game crashes at the end of the initial loading phase,
+## right before showing the game menu, with the following trace:
+##
+## [FMOD] d:\Jenkins\workspace\Ursa_SDL2\GSGE\GSGE\Code\Audio\AudioManager.cs:ln - 597 Unsupported file or audio format. Failed to create VO sound bank: Content/Audio/FMOD/Build/Desktop/VO.fsb
+##   at GSGE.AudioManager.LoadVoiceBank () [0x0034a] in <160751e4f5c141ae8efac1285e76459f>:0
+##   at GSGE.AudioManager.Preload () [0x00021] in <160751e4f5c141ae8efac1285e76459f>:0
+##   at GSGE.Code.GUI.LaunchScreen+<>c__DisplayClassc.<MapLoad>b__9 () [0x00040] in <160751e4f5c141ae8efac1285e76459f>:0
+##   at System.Threading.Tasks.Task.InnerInvoke () [0x00012] in <12b418a7818c4ca0893feeaaf67f1e7f>:0
+##   at System.Threading.Tasks.Task.Execute () [0x00000] in <12b418a7818c4ca0893feeaaf67f1e7f>:0
+##
+## To work around it, we use the shipped Mono binaries instead of system-provided Mono.
 APP_MAIN_EXE_BIN64='Pyre.bin.x86_64'
 APP_MAIN_EXE_BIN32='Pyre.bin.x86'
 APP_MAIN_ICON='PyreIcon.bmp'
@@ -79,8 +89,6 @@ PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -95,8 +103,6 @@ libSDL2_image-2.0.so.0
 libstdc++.so.6
 libudev.so.1
 libz.so.1'
-PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
-PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -146,6 +152,14 @@ content_inclusion_default
 APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
 $(mono_launcher_tweaks)"
 
+## This game expects an executable stack through dynamically loaded libraries.
+game_exec_line() {
+	local application="$1" application_exe
+	application_exe=$(application_exe "$application")
+	cat <<- EOF
+	GLIBC_TUNABLES=glibc.rtld.execstack=2 "./${application_exe}" "\$@"
+	EOF
+}
 launchers_generation 'PKG_BIN64'
 launchers_generation 'PKG_BIN32'
 
