@@ -8,23 +8,23 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250504.1
+script_version=20250917.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
 
+ARCHIVE_BASE_61_NAME='stellaris_4_0_23_84679.sh'
+ARCHIVE_BASE_61_MD5='72012fb6ce1ecd9c729e3ceb04fbba2a'
+ARCHIVE_BASE_61_SIZE='22711133'
+ARCHIVE_BASE_61_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_61_URL='https://www.gog.com/game/stellaris'
+
 ARCHIVE_BASE_60_NAME='stellaris_3_14_1592653_81105.sh'
 ARCHIVE_BASE_60_MD5='1cc50dc7470ed4ddd58fc755e9cf3024'
 ARCHIVE_BASE_60_SIZE='20346386'
 ARCHIVE_BASE_60_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_60_URL='https://www.gog.com/game/stellaris'
-
-ARCHIVE_BASE_59_NAME='stellaris_3_14_15926_78464.sh'
-ARCHIVE_BASE_59_MD5='0e93163e55e8bddbcdfd6c7c9c0307bd'
-ARCHIVE_BASE_59_SIZE='20344787'
-ARCHIVE_BASE_59_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_58_NAME='stellaris_3_13_2_0_76713.sh'
 ARCHIVE_BASE_58_MD5='e8a71267c39846f3fa51a7f14f0d2177'
@@ -203,7 +203,7 @@ libpthread.so.0
 libstdc++.so.6
 libX11.so.6'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -229,33 +229,33 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-## Force the use of system-provided SDL
+## Force the use of system-provided SDL.
 APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
 $(launcher_tweak_sdl_override)"
 
 launchers_generation 'PKG_BIN'
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
