@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Tyranny
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241229.1
+script_version=20250429.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='tyranny'
 GAME_NAME='Tyranny'
@@ -44,8 +45,6 @@ PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -65,8 +64,6 @@ libX11.so.6
 libXcursor.so.1
 libXrandr.so.2
 libz.so.1'
-PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
-PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
